@@ -7,7 +7,7 @@ package Plack::Middleware::Statsd;
 # RECOMMEND PREREQ: List::Util::XS
 # RECOMMEND PREREQ: Ref::Util::XS
 
-use v5.14;
+use v5.20;
 use warnings;
 
 use parent qw/ Plack::Middleware /;
@@ -20,15 +20,16 @@ use Ref::Util qw/ is_coderef /;
 use Time::HiRes;
 use Try::Tiny;
 
-our $VERSION = 'v0.6.3';
+use experimental qw/ postderef signatures /;
+
+our $VERSION = 'v0.7.0';
 
 # Note: You may be able to omit the client if there is a client
 # defined in the environment hash at C<psgix.monitor.statsd>, and the
 # L</histogram>, L</increment> and L</attributes> are set.  But that
 # is a strange case and unsupported.
 
-sub prepare_app {
-    my ($self) = @_;
+sub prepare_app($self) {
 
     if ( my $client = $self->client ) {
         foreach my $init (
@@ -37,15 +38,14 @@ sub prepare_app {
             [qw/ set_add   set_add   /],
           )
         {
-            my ( $attr, @methods ) = @$init;
+            my ( $attr, @methods ) = $init->@*;
             next if defined $self->$attr;
             my $method = first { $client->can($_) } @methods;
             warn "No $attr method found for client " . ref($client)
                 unless defined $method;
             $self->$attr(
-                sub {
+                sub($env, @args) {
                     return unless defined $method;
-                    my ($env, @args) = @_;
                     try {
                         $client->$method( grep { defined $_ } @args );
                     }
@@ -73,8 +73,7 @@ sub prepare_app {
         unless ( is_coderef($catch) ) {
 
             $self->catch_errors(
-                sub {
-                    my ( $env, $error ) = @_;
+                sub( $env, $error ) {
                     if ( my $logger = $env->{'psgix.logger'} ) {
                         $logger->( { level => 'error', message => $error } );
                     }
@@ -91,8 +90,7 @@ sub prepare_app {
     }
 }
 
-sub call {
-    my ( $self, $env ) = @_;
+sub call ( $self, $env ) {
 
     my $client = ( $env->{'psgix.monitor.statsd'} //= $self->client );
 
@@ -113,11 +111,9 @@ sub call {
 
     return Plack::Util::response_cb(
         $res,
-        sub {
+        sub($res) {
             return unless $client;
 
-            my ($res) = @_;
-
             my $rate = $self->sample_rate;
 
             $rate = undef if ( defined $rate ) && ( $rate >= 1 );
@@ -189,8 +185,8 @@ sub call {
 
 }
 
-sub _mime_type_to_metric {
-    my $type = $_[0] or return;
+sub _mime_type_to_metric( $type = undef ) {
+    return unless $type;
     return $type =~ s#\.#-#gr =~ s#/#.#gr =~ s/;.*$//r;
 }
 
@@ -209,7 +205,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.6.3
+version v0.7.0
 
 =head1 SYNOPSIS
 
@@ -504,14 +500,10 @@ need to add metrics logging yourself.
 
 =head1 SUPPORT FOR OLDER PERL VERSIONS
 
-Since v0.6.0, the this module requires Perl v5.14 or later.
+Since v0.7.0, the this module requires Perl v5.20 or later.
 
 Future releases may only support Perl versions released in the last ten years.
 
-If you need this module on Perl v5.10, please use one of the v0.5.x
-versions of this module.  Significant bug or security fixes may be
-backported to those versions.
-
 =head1 SEE ALSO
 
 L<Net::Statsd::Client>
